//
//  GLMultiPointGeometry.h
//  GLGeometry
//
//  Created by Jeffrey Early on 4/30/06.
//  Copyright 2006 Early Innovation. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <GLGeometryKit/GLGeometry.h>

// A MultiPoint is a 0 dimensional geometric collection. The elements of a
// MultiPoint are restricted to Points. The points are not connected or ordered.

@class GLClippingRegion;
@interface GLMultiPointGeometry : GLGeometry {
	GLMultiPoint * aMultiPoint;
    
    NSMutableData *clippedMultiPointData;
	GLMultiPointPtr clippiedMultiPoint;
    
    NSMutableData *clippedLineStringData;
	GLLineStringPtr clippedLineString;
}

/************************************************/
/*		Object Initialization					*/
/************************************************/

#pragma mark -
#pragma mark Object Initialization
#pragma mark

// initialize using an GLMultiPoint
- (id) initWithMultiPoint: (GLMultiPoint) multiPoint;

// initialize using an GLMultiPointPtr
- (id) initWithMultiPointPtr: (GLMultiPointPtr) multiPoint;

/************************************************/
/*			Accessor Methods					*/
/************************************************/

#pragma mark -
#pragma mark Accessor Methods
#pragma mark

// Calling -set makes a clean copy of the structure.
@property GLMultiPointPtr multiPointGeometry;

/************************************************/
/*			Clipping Methods                    */
/************************************************/

#pragma mark -
#pragma mark Clipping Methods
#pragma mark

// I don't yet like the way that this is structured. So we'll want to come back and
// change this when we start dealing with the more general case.

// Returns a primitive geometry clipped and transformed according to the clipping region.
// The resulting GLMultiPointPtr is locally cached until the GLClippingRegion object disappears.
- (GLMultiPointPtr) clippedMultiPointWithRegion: (GLClippingRegion *) clippingRegion;

// Clip a MultiPoint as if it is a line string
- (GLLineStringPtr) clippedLineStringWithRegion: (GLClippingRegion *) clippingRegion;

@end
