//
//  GLPolygonGeometry.h
//  GLGeometry
//
//  Created by Jeffrey Early on 10/20/06.
//  Copyright 2006 Early Innovation. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <GLGeometryKit/GLGeometry.h>

@class GLClippingRegion;
@interface GLPolygonGeometry : GLGeometry {
	GLPolygonPtr aPolygon;
	
	GLPolygonPtr _clippedPolygon;
	GLPointPtr centroid;
	
	// Experimental
	GLPolygonGeometry * _transformedPolygon;
	NSInteger _transformedPolygonSRID;
	GLPoint _transformedBounds[4];
}

/************************************************/
/*		Object Initialization					*/
/************************************************/

#pragma mark -
#pragma mark Object Initialization
#pragma mark

- (id) initWithPolygon: (GLPolygon) polygon;

- (id) initWithPolygonPtr: (GLPolygonPtr) polygon;

/************************************************/
/*			Accessor Methods					*/
/************************************************/

#pragma mark -
#pragma mark Accessor Methods
#pragma mark

// Calling -set makes a clean copy of the structure.
@property GLPolygonPtr polygonGeometry;

/************************************************/
/*			Other Methods                       */
/************************************************/

#pragma mark -
#pragma mark Other Methods
#pragma mark

// Returns a primitive geometry clipped and transformed according to the clipping region.
// The resulting GLPolygonPtr is locally cached until the GLClippingRegion object disappears.
- (GLPolygonPtr) clippedPolygonWithRegion: (GLClippingRegion *) clippingRegion;

// Okay, maybe not centroid -- we grab the ring with the largest area. This doens't even make sense
// because rings can represent holes, but oh well.
- (GLPointPtr) centroid;

@end